@@ -26,8 +26,8 @@ use strict;
 use warnings;
 
 package DUCK;
-my $VERSION ='0.10';
-my $COPYRIGHT_YEAR ='2016';
+my $VERSION ='0.12';
+my $COPYRIGHT_YEAR ='2017';
 
 my $default_user_agent='Mozilla/5.0 (X11; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0';
 
@@ -285,13 +285,12 @@ sub try_https_new($;$)
 
     # otherwise check similarity, and report if pages are (quite) the same 
 
-    if ($erghttps && $erghttps->{'retval'} == 0 && $erghttp && $erghttp->{'body'} && $erghttp->{'finalscheme'} eq "https")
+    if ($erghttps && $erghttps->{'retval'} == 0 && $erghttp && $erghttp->{'body'} && $erghttp->{'finalscheme'} eq "http")
     {
 	# https worked, now try to find out if pages match
 #	print "#####################1\n".$erghttp->{'body'}."\n\n".$erghttps->{'body'}."\n\n";
 	my $similarity= similarity $erghttp->{'body'}, $erghttps->{'body'};
 	
-
 	if ($similarity > $similarity_th)
 	{
 	    $res->{'retval'}=2;
@@ -471,6 +470,11 @@ sub __run_browser {
 	$cli_options->{'no-https'}=0;
     }
 
+       if (! ( $cli_options->{'no-check-certificate'}))
+    {
+	$cli_options->{'no-check-certificate'}=0;
+    }
+
 
     #check if URL is mailto: link
     
@@ -484,8 +488,10 @@ sub __run_browser {
     my @website_moved_whitelist=('anonscm.debian.org.*duck.git');
     
     $curl->setopt(CURLOPT_HEADER,0);
+    if ($cli_options->{'no-check-certificate'} eq 1) {
     $curl->setopt(CURLOPT_SSL_VERIFYPEER,0);
     $curl->setopt(CURLOPT_SSL_VERIFYHOST,0);
+    }
     $curl->setopt(CURLOPT_CERTINFO,0);
     $curl->setopt(CURLOPT_FOLLOWLOCATION,1);
     $curl->setopt(CURLOPT_SSL_CIPHER_LIST,'ALL');
@@ -499,8 +505,7 @@ sub __run_browser {
 #    $curl->setopt(CURLOPT_SSL_VERIFYPEER,1);
 #    $curl->setopt(CURLOPT_SSL_VERIFYHOST,1);
 #    $curl->setopt(CURLOPT_CAPATH,'');
-    
-    
+
     my $response_body;
     my $response_code;
     my $retcode;
@@ -636,7 +641,6 @@ sub __run_browser {
     $ret->{'finalscheme'}=$finalscheme;
     $ret->{'finaldomain'}=$finaldomain;
     
-    
     my @reta;
     push(@reta,$ret);
     if ($startscheme && $finalscheme)
